@@ -1,16 +1,22 @@
 package URI::Fast;
-$URI::Fast::VERSION = '0.13';
+$URI::Fast::VERSION = '0.14';
 # ABSTRACT: A fast(er) URI parser
 
 use utf8;
 use strict;
 use warnings;
 no strict 'refs';
-
 use Carp;
-use Inline C => 'lib/uri_fast.c' => optimize => '-O2';
-
+require Inline;
 require Exporter;
+require File::Spec;
+
+# Build
+my $path = File::Spec->rel2abs(__FILE__);
+$path =~ s/\.pm$//;
+$path .= '/uri_fast.c';
+Inline->bind(C => $path => optimize => '-O2');
+
 use parent 'Exporter';
 our @EXPORT_OK = qw(uri uri_split);
 
@@ -139,7 +145,7 @@ URI::Fast - A fast(er) URI parser
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
